INITIAL_COMMIT = "Initial commit"

COMMIT_DELIMITER = "--commit-delimiter--"

FAILED = "Commit validation: failed!"

TITLE_FAILED = "Please enter a commit message in the conventional commits format."

BODY_FAILED = (
    "The body of the commit message contains a conventional commit prefix.\n"
    "This should only appear in the title of the commit.\n"
    "Did you forget to edit and clean up the commit message after a squash?"
)

SUCCESS = "Commit validation: success!"

EMOJI_CHECK = ":check_mark_button:"
EMOJI_CROSS = ":cross_mark:"

PATTERN = (
    r"(?s)"  # To explictly make . match new line
    r"(build|ci|docs|feat|fix|perf|refactor|style|test|chore|revert|bump|enabler)"  # type
    r"(\(\S+\))?!?:"  # scope
    r"( [^\n\r]+)"  # subject
    r"((\n\n.*)|(\s*))?$"
)
